# Polymer-Plotting
Plotting various models for polymers in python.

This package should be used to run an easy to use GUI for plotting different models of polymer chains

DISCLAIMER: This program was written by a student with < 1 year coding experience.
Some bits may not be best optimised, pls no hate, feedback always welcome :)

This is also the first time I've used GitHub and have absolutely no clue what I'm doing.

Python dependencies are: Numpy, Matplotlib and PySimpleGUI.
